@@ -1,7 +1,10 @@
 
-MSGHD <- function(data=NULL, gpar0=NULL, G=2, max.iter=100, label =NULL , method="kmeans" ) {
+MSGHD <- function(data=NULL, gpar0=NULL, G=2, max.iter=100, label =NULL , method="kmeans",scale=TRUE ) {
     data=as.matrix(data)
-    data=scale(data)
+    if( scale==TRUE)
+    {data=scale(data)}
+    pcol=ncol(data)
+    if (nrow(data)<((G-1)+G*(4*pcol+pcol*(pcol-1)/2)))stop('G is too big, number of parameters > n')
     if (is.null(data)) stop('data is null')
     if (nrow(data) == 1) stop('nrow(data) is equal to 1')
     if (ncol(data) == 1) stop('ncol(data) is equal to 1; This function currently only works with multivariate data p > 1')
@@ -18,7 +21,7 @@ MSGHD <- function(data=NULL, gpar0=NULL, G=2, max.iter=100, label =NULL , method
         gpar = EMgrstepMS(data=data, gpar=gpar, v=1, label = label)
         loglik[i] = llikMS(data, gpar)
     }
-    pcol=ncol(data)
+    
     BIC=2*loglik[n]-log(nrow(data))*((G-1)+G*(4*pcol+pcol*(pcol-1)/2))
     val = list(loglik= loglik, gpar=gpar, z=weightsMS(data=data, gpar= gpar), map=MAPMS(data=data, gpar= gpar, label=label), BIC=BIC)
     return(val)
